package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.TaxiPricesMapper;
import com.ruoyi.system.domain.TaxiPrices;
import com.ruoyi.system.service.ITaxiPricesService;

/**
 * TaxiPricesService业务层处理
 * 
 * @author ruoyi
 * @date 2024-01-26
 */
@Service
public class TaxiPricesServiceImpl extends ServiceImpl<BaseMapper<TaxiPrices>,TaxiPrices> implements ITaxiPricesService
{
    @Autowired
    private TaxiPricesMapper taxiPricesMapper;

    /**
     * 查询TaxiPrices
     * 
     * @param id TaxiPrices主键
     * @return TaxiPrices
     */
    @Override
    public TaxiPrices selectTaxiPricesById(Long id)
    {
        return taxiPricesMapper.selectTaxiPricesById(id);
    }

    /**
     * 查询TaxiPrices列表
     * 
     * @param taxiPrices TaxiPrices
     * @return TaxiPrices
     */
    @Override
    public List<TaxiPrices> selectTaxiPricesList(TaxiPrices taxiPrices)
    {
        return taxiPricesMapper.selectTaxiPricesList(taxiPrices);
    }

    /**
     * 新增TaxiPrices
     * 
     * @param taxiPrices TaxiPrices
     * @return 结果
     */
    @Override
    public int insertTaxiPrices(TaxiPrices taxiPrices)
    {
        return taxiPricesMapper.insertTaxiPrices(taxiPrices);
    }

    /**
     * 修改TaxiPrices
     * 
     * @param taxiPrices TaxiPrices
     * @return 结果
     */
    @Override
    public int updateTaxiPrices(TaxiPrices taxiPrices)
    {
        return taxiPricesMapper.updateTaxiPrices(taxiPrices);
    }

    /**
     * 批量删除TaxiPrices
     * 
     * @param ids 需要删除的TaxiPrices主键
     * @return 结果
     */
    @Override
    public int deleteTaxiPricesByIds(Long[] ids)
    {
        return taxiPricesMapper.deleteTaxiPricesByIds(ids);
    }

    /**
     * 删除TaxiPrices信息
     * 
     * @param id TaxiPrices主键
     * @return 结果
     */
    @Override
    public int deleteTaxiPricesById(Long id)
    {
        return taxiPricesMapper.deleteTaxiPricesById(id);
    }
}
